Object = require "classic"
require "player"
require "bullet"
require "enemy"

-- constants
WINDOW_WIDTH = 1024
WINDOW_HEIGHT = 768


function love.load()
	-- window
	love.window.setMode(WINDOW_WIDTH, WINDOW_HEIGHT, {resizable = false, vsync = true})
	love.graphics.setDefaultFilter('nearest', 'nearest')
	love.window.setTitle("Space Invaders")
	
	-- graphics
	background = love.graphics.newImage("background.png")
	ground = love.graphics.newImage("ground.png")
	spritesheet = love.graphics.newImage("sprites.png")
	
	rocket = love.graphics.newQuad(0,0,16,16,spritesheet:getDimensions())
	alien1 = love.graphics.newQuad(16,0,16,16,spritesheet:getDimensions())
	alien2 = love.graphics.newQuad(32,0,16,16,spritesheet:getDimensions())
	alien3 = love.graphics.newQuad(48,0,16,16,spritesheet:getDimensions())
	bullet = love.graphics.newQuad(64,0,16,16,spritesheet:getDimensions())
	charge = love.graphics.newQuad(80,0,16,16,spritesheet:getDimensions())
	heart = love.graphics.newQuad(96,0,16,16,spritesheet:getDimensions())
	
	-- sounds
	shoot = love.audio.newSource("shoot.wav", "static")
	hit = love.audio.newSource("hit.wav", "static")
	gameover = love.audio.newSource("gameover.wav", "static")
	
	-- varibles
	player = Player(512, 576, 3)
	bullets = {} -- table of bullets	
	enemies = {}
	
	spawn_enemies()
end

function spawn_enemies()
	enemy_speed = 150
	table.insert(enemies, Enemy(0, 0, "alien3", enemy_speed))
	table.insert(enemies, Enemy(64, 0, "alien3", enemy_speed))
	table.insert(enemies, Enemy(128, 0, "alien3", enemy_speed))
	table.insert(enemies, Enemy(192, 0, "alien3", enemy_speed))
	table.insert(enemies, Enemy(256, 0, "alien3", enemy_speed))
	table.insert(enemies, Enemy(320, 0, "alien3", enemy_speed))
	table.insert(enemies, Enemy(384, 0, "alien3", enemy_speed))
	table.insert(enemies, Enemy(448, 0, "alien3", enemy_speed))
	table.insert(enemies, Enemy(512, 0, "alien3", enemy_speed))
	table.insert(enemies, Enemy(576, 0, "alien3", enemy_speed))
	table.insert(enemies, Enemy(0, 64, "alien2", enemy_speed))
	table.insert(enemies, Enemy(64, 64, "alien2", enemy_speed))
	table.insert(enemies, Enemy(128, 64, "alien2", enemy_speed))
	table.insert(enemies, Enemy(192, 64, "alien2", enemy_speed))
	table.insert(enemies, Enemy(256, 64, "alien2", enemy_speed))
	table.insert(enemies, Enemy(320, 64, "alien2", enemy_speed))
	table.insert(enemies, Enemy(384, 64, "alien2", enemy_speed))
	table.insert(enemies, Enemy(448, 64, "alien2", enemy_speed))
	table.insert(enemies, Enemy(512, 64, "alien2", enemy_speed))
	table.insert(enemies, Enemy(576, 64, "alien2", enemy_speed))
	table.insert(enemies, Enemy(0, 128, "alien1", enemy_speed))
	table.insert(enemies, Enemy(64, 128, "alien1", enemy_speed))
	table.insert(enemies, Enemy(128, 128, "alien1", enemy_speed))
	table.insert(enemies, Enemy(192, 128, "alien1", enemy_speed))
	table.insert(enemies, Enemy(256, 128, "alien1", enemy_speed))
	table.insert(enemies, Enemy(320, 128, "alien1", enemy_speed))
	table.insert(enemies, Enemy(384, 128, "alien1", enemy_speed))
	table.insert(enemies, Enemy(448, 128, "alien1", enemy_speed))
	table.insert(enemies, Enemy(512, 128, "alien1", enemy_speed))
	table.insert(enemies, Enemy(576, 128, "alien1", enemy_speed))
end

function enemies_jump()
	for i, enemy in pairs (enemies) do
		enemy:jump()
		print("Enemy"..i.. " x:" .. enemy.x .. " y: " .. enemy.y .. " speed: " .. enemy.x_speed)
	end
end

function love.update(dt)
	player:update(dt)
	for index, bullet in pairs (bullets) do 
		bullet:update(dt)
		if bullet.y + bullet.height < 0 then
			table.remove(bullets, index)
		end
	end
	for i, enemy in pairs (enemies) do
		enemy:update(dt)
	end
end

function love.draw()
	love.graphics.draw(background, 0, 0)
	love.graphics.draw(ground, 0, 640, 0, 4, 4)
	player:draw()
	for index,bullet in pairs (bullets) do
		bullet:draw()
	end
	for i, enemy in pairs (enemies) do
		enemy:draw()
	end
end